@@ -61,7 +61,7 @@ use constant CODE_REF	=> ref sub {};
     our @EXPORT = @funcs;	## no critic (ProhibitAutomaticExportation)
 }
 
-our $VERSION = '0.012_02';
+our $VERSION = '0.013_01';
 our $XS_VERSION = $VERSION;
 our $ALPHA_VERSION = $VERSION;
 $VERSION =~ s/_//g;
@@ -1170,8 +1170,9 @@ earlier versions.
 
 =head1 BUGS
 
-Please report bugs either through
-L<https://github.com/trwyant/perl-Mac-Pasteboard/issues/> or by mail to
+Please report bugs through
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Mac-Pasteboard>,
+L<https://github.com/trwyant/perl-Mac-Pasteboard/issues/>, or by mail to
 the author.
 
 =head1 SEE ALSO
